@@ -1,4 +1,4 @@
-using namespace std;
+// using namespace std;
 
 //  #include "tntsupp.h"
 //  #include "geese.h"
@@ -307,8 +307,12 @@ void gee_est(DVector &Y, DMatrix &X,
   int iter; double del;
   for (iter = 0; iter < con.maxiter(); iter++) {
     if (con.trace() == 1) {
-      cerr << "iter " << iter << endl;
-      cerr << "beta = " << par.beta() << "gamma = " << par.gamma() << "alpha = " << par.alpha();
+      //cerr << "iter " << iter << endl;
+      //cerr << "beta = " << par.beta() << "gamma = " << par.gamma() << "alpha = " << par.alpha();
+      Rprintf("iter = %d\n", iter);
+      Rprintf("beta = "); VecPrint(par.beta()); 
+      Rprintf("gamma = "); VecPrint(par.gamma());
+      Rprintf("alpha = "); VecPrint(par.alpha());
     }
     //updating beta;
     Phi = getPhi(Doffset, Zsca, LinkWave, par, geestr);
@@ -472,8 +476,14 @@ extern "C" {
     DMatrix X = asDMatrix(x), Zsca = asDMatrix(zsca), Zcor = asDMatrix(zcor);
     IVector Clusz = asIVector(clusz); // ZcorSize = asIVector(zcorsize);
     Control Con = asControl(con);   
-    GeeParam Par = asGeeParam(par);   
-    GeeStr Geestr = asGeeStr(geestr);   
+    GeeParam Par = asGeeParam(par);
+
+    SEXP geestr_protect;
+    PROTECT(geestr_protect = geestr);
+    GeeStr Geestr = asGeeStr(geestr_protect);
+    UNPROTECT(1);
+    
+    //GeeStr Geestr = asGeeStr(geestr);   
     Corr Cor = asCorr(cor);   
 
     gee_top(Y, X, Offset, Doffset, W, LinkWave, Zsca, Zcor, CorP, Clusz, Geestr, Cor, Par, Con);
@@ -491,8 +501,13 @@ extern "C" {
     DMatrix X = asDMatrix(x), Zsca = asDMatrix(zsca), Zcor = asDMatrix(zcor);
     IVector Clusz = asIVector(clusz); // ZcorSize = asIVector(zcorsize);
     Control Con = asControl(con);   
-    GeeParam Par = asGeeParam(par);   
-    GeeStr Geestr = asGeeStr(geestr);   
+    GeeParam Par = asGeeParam(par);
+
+    SEXP geestr_protect;
+    PROTECT(geestr_protect = geestr);
+    GeeStr Geestr = asGeeStr(geestr_protect);
+    
+      //GeeStr Geestr = asGeeStr(geestr);   
     Corr Cor = asCorr(cor);   
 
     DMatrix infls = gee_infls(Y, X, Offset, Doffset, W, LinkWave, Zsca, Zcor, CorP, Clusz, Geestr, Cor, Par, Con);
